@@ -1,4 +1,4 @@
-from decaptcha import *
+from decaptcha.notarobot import NotARobot, OpenGround
 import pytest
 import pyautogui
 from selenium import webdriver
@@ -37,6 +37,11 @@ def test_bot(bot):
     assert bot.state.victory == True or bot.state.killswitch == True
 
 
+def test_reset(bot):
+    bot.reset()
+    assert isinstance(bot.state, OpenGround)
+
+
 def test_teardown(browser):
     browser.close()
     browser.quit()
