@@ -7,11 +7,11 @@ def bot():
     return DispersiveGround()
 
 
-def test_edge_collision(bot):
+def test_is_collision(bot):
     assert bot.is_collision(tuple([1, 3]), tuple([2, 4]))
-    assert bot.is_collision(tuple([1, 3]), tuple([3, 5]))
+    assert not bot.is_collision(tuple([1, 3]), tuple([3, 5]))
     assert bot.is_collision(tuple([2, 4]), tuple([1, 3]))
-    assert bot.is_collision(tuple([3, 5]), tuple([1, 3]))
+    assert not bot.is_collision(tuple([3, 5]), tuple([1, 3]))
     assert not bot.is_collision(tuple([1, 3]), tuple([4, 6]))
     assert not bot.is_collision(tuple([4, 6]), tuple([1, 3]))
 
